@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Classic;
 
-our $DATE = '2015-09-18'; # DATE
-our $VERSION = '1.58'; # VERSION
+our $DATE = '2015-09-29'; # DATE
+our $VERSION = '1.59'; # VERSION
 
 use 5.010001;
 #use strict; # enabled by Moo
@@ -511,7 +511,7 @@ sub hook_format_result {
         $fres = $res->[2];
     } else {
         $log->tracef("Formatting output with %s", $format);
-        $fres = Perinci::Result::Format::format($res, $format);
+        $fres = Perinci::Result::Format::format($res, $format, $r->{naked_res});
     }
 
     # ux: prefix error message with program name
@@ -785,7 +785,7 @@ Perinci::CmdLine::Classic - Rinci/Riap-based command-line application framework
 
 =head1 VERSION
 
-This document describes version 1.58 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-18.
+This document describes version 1.59 of Perinci::CmdLine::Classic (from Perl distribution Perinci-CmdLine-Classic), released on 2015-09-29.
 
 =head1 SYNOPSIS
 
@@ -889,11 +889,12 @@ Automatic tab completion support:
  % complete -C gen-random-num gen-random-num
  % gen-random-num --mi<tab>
 
-See the manual for details on other available features (subcommands, automatic
-formatting of data structures, automatic schema validation, dry-run mode,
-automatic POD generation, remote function support, automatic CLI generation,
-automatic --version, automatic HTTP API, undo/transactions, configurable output
-format, logging, progress bar, colors/Unicode, and more).
+See L<Perinci::CmdLine::Manual> for details on other available features
+(subcommands, automatic formatting of data structures, automatic schema
+validation, dry-run mode, automatic POD generation, remote function support,
+automatic CLI generation, automatic --version, automatic HTTP API,
+undo/transactions, configurable output format, logging, progress bar,
+colors/Unicode, and more).
 
 =head1 DESCRIPTION
 
